==> fluxbb-1.4.2p2.tgz: fluxbb/lang/English/admin_groups.php <==
<?php

// Language definitions used in admin-groups.php
$lang_admin_groups = array(

'Must enter title message'		=>	'You must enter a group title.',
'Title already exists message'	=>	'There is already a group with the title <strong>%s</strong>.',
'Default group redirect'		=>	'Default group set. Redirecting …',
'Cannot remove default message'	=>	'The default group cannot be removed. In order to delete this group, you must first setup a different group as the default.',
'Group removed redirect'		=>	'Group removed. Redirecting …',
'Group added redirect'			=>	'Group added. Redirecting …',
'Group edited redirect'			=>	'Group edited. Redirecting …',

'Add groups head'				=>	'Add/setup groups',
'Add group subhead'				=>	'Add new group',
'New group label'				=>	'Base new group on',
'New group help'				=>	'Select a user group from which the new group will inherit its permission settings. The next page will let you fine-tune its settings.',
'Default group subhead'			=>	'Set default group',
'Default group label'			=>	'Default group',
'Default group help'			=>	'This is the default user group, e.g. the group users are placed in when they register. For security reasons, users can\'t be placed in either the moderator or administrator user groups by default.',
'Existing groups head'			=>	'Existing groups',
'Edit groups subhead'			=>	'Edit/delete groups',
'Edit groups info'				=>	'The pre-defined groups Guests, Administrators, Moderators and Members cannot be removed. However, they can be edited. Please note that in some groups, some options are unavailable (e.g. the <em>edit posts</em> permission for guests). Administrators always have full permissions.',
'Edit link'						=>	'Edit',
'Delete link'					=>	'Delete',
'Group delete head'				=>	'Group delete',
'Confirm delete subhead'		=>	'Confirm delete group',
'Confirm delete info'			=>	'Are you sure that you want to delete the group <strong>%s</strong>?',
'Confirm delete warn'			=>	'WARNING! After you deleted a group you can not restore it.',
'Delete group head'				=>	'Delete group',
'Move users subhead'			=>	'Move users currently in group',
'Move users info'				=>	'The group <strong>%s</strong> currently has <strong>%s</strong> members. Please select a group to which these members will be assigned upon deletion.',
'Move users label'				=>	'Move users to',
'Delete group'					=>	'Delete group',

'Group settings head'			=>	'Group settings',
'Group settings subhead'		=>	'Setup group options and permissions',
'Group settings info'			=>	'Below options and permissions are the default permissions for the user group. These options apply if no forum specific permissions are in effect.',
'Group title label'				=>	'Group title',
'User title label'				=>	'User title',
'User title help'				=>	'This title will override any rank users in this group have attained. Leave blank to use default title or rank.',
'Mod privileges label'			=>	'Allow users moderator privileges',
'Mod privileges help'			=>	'In order for a user in this group to have moderator abilities, he/she must be assigned to moderate one or more forums. This is done via the user administration page of the user\'s profile.',
'Edit profile label'			=>	'Allow moderators to edit user profiles',
'Edit profile help'				=>	'If moderator privileges are enabled, allow users in this group to edit user profiles.',
'Rename users label'			=>	'Allow moderators to rename users',
'Rename users help'				=>	'If moderator privileges are enabled, allow users in this group to rename users.',
'Change passwords label'		=>	'Allow moderators to change passwords',
'Change passwords help'			=>	'If moderator privileges are enabled, allow users in this group to change user passwords.',
'Ban users label'				=>	'Allow moderators to ban users',
'Ban users help'				=>	'If moderator privileges are enabled, allow users in this group to ban users.',
'Read board label'				=>	'Read board',
'Read board help'				=>	'Allow users in this group to view the board. This setting applies to every aspect of the board and can therefore not be overridden by forum specific settings. If this is set to "No", users in this group will only be able to login/logout and register.',
'View user info label'			=>	'View user information',
'View user info help'			=>	'Allow users to view the user list and user profiles.',
'Post replies label'			=>	'Post replies',
'Post replies help'				=>	'Allow users in this group to post replies in topics.',
'Post topics label'				=>	'Post topics',
'Post topics help'				=>	'Allow users in this group to post new topics.',
'Edit posts label'				=>	'Edit posts',
'Edit posts help'				=>	'Allow users in this group to edit their own posts.',
'Delete posts label'			=>	'Delete posts',
'Delete posts help'				=>	'Allow users in this group to delete their own posts.',
'Delete topics label'			=>	'Delete topics',
'Delete topics help'			=>	'Allow users in this group to delete their own topics (including any replies).',
'Set own title label'			=>	'Set own user title',
'Set own title help'			=>	'Allow users in this group to set their own user title.',
'User search label'				=>	'Use search',
'User search help'				=>	'Allow users in this group to use the search feature.',
'User list search label'		=>	'Search user list',
'User list search help'			=>	'Allow users in this group to freetext search for users in the user list.',
'Send e-mails label'			=>	'Send e-mails',
'Send e-mails help'				=>	'Allow users in this group to send e-mails to other users.',
'Post flood label'				=>	'Post flood interval',
'Post flood help'				=>	'Number of seconds that users in this group have to wait between posts. Set to 0 to disable.',
'Search flood label'			=>	'Search flood interval',
'Search flood help'				=>	'Number of seconds that users in this group have to wait between searches. Set to 0 to disable.',
'E-mail flood label'			=>	'Email flood interval',
'E-mail flood help'				=>	'Number of seconds that users in this group have to wait between emails. Set to 0 to disable.',
'Moderator info'				=>	'Please note that in order for a user in this group to have moderator abilities, he/she must be assigned to moderate one or more forums. This is done via the user administration page of the user\'s profile.',

);

==> fluxbb-1.5.0p0.tgz: fluxbb/lang/English/admin_groups.php <==
<?php

// Language definitions used in admin-groups.php
$lang_admin_groups = array(

'Must enter title message'		=>	'You must enter a group title.',
'Title already exists message'	=>	'There is already a group with the title <strong>%s</strong>.',
'Default group redirect'		=>	'Default group set. Redirecting …',
'Cannot remove default message'	=>	'The default group cannot be removed. In order to delete this group, you must first setup a different group as the default.',
'Group removed redirect'		=>	'Group removed. Redirecting …',
'Group added redirect'			=>	'Group added. Redirecting …',
'Group edited redirect'			=>	'Group edited. Redirecting …',

'Add groups head'				=>	'Add/setup groups',
'Add group subhead'				=>	'Add new group',
'New group label'				=>	'Base new group on',
'New group help'				=>	'Select a user group from which the new group will inherit its permission settings. The next page will let you fine-tune its settings.',
'Default group subhead'			=>	'Set default group',
'Default group label'			=>	'Default group',
'Default group help'			=>	'This is the default user group, e.g. the group users are placed in when they register. For security reasons, users can\'t be placed in either the moderator or administrator user groups by default.',
'Existing groups head'			=>	'Existing groups',
'Edit groups subhead'			=>	'Edit/delete groups',
'Edit groups info'				=>	'The pre-defined groups Guests, Administrators, Moderators and Members cannot be removed. However, they can be edited. Please note that in some groups, some options are unavailable (e.g. the <em>edit posts</em> permission for guests). Administrators always have full permissions.',
'Edit link'						=>	'Edit',
'Delete link'					=>	'Delete',
'Group delete head'				=>	'Group delete',
'Confirm delete subhead'		=>	'Confirm delete group',
'Confirm delete info'			=>	'Are you sure that you want to delete the group <strong>%s</strong>?',
'Confirm delete warn'			=>	'WARNING! After you deleted a group you cannot restore it.',
'Delete group head'				=>	'Delete group',
'Move users subhead'			=>	'Move users currently in group',
'Move users info'				=>	'The group <strong>%s</strong> currently has <strong>%s</strong> members. Please select a group to which these members will be assigned upon deletion.',
'Move users label'				=>	'Move users to',
'Delete group'					=>	'Delete group',

'Group settings head'			=>	'Group settings',
'Group settings subhead'		=>	'Setup group options and permissions',
'Group settings info'			=>	'Below options and permissions are the default permissions for the user group. These options apply if no forum specific permissions are in effect.',
'Group title label'				=>	'Group title',
'User title label'				=>	'User title',
'User title help'				=>	'The rank users in this group have attained. Leave blank to use default title ("%s").',
'Promote users label'			=>	'Promote users',
'Promote users help'			=>	'You can promote users to a new group automatically if they reach a certain number of posts. Select "%s" to disable. For security reasons, you are not allowed to select an administrator group here. Also note that group changes for users affected by this setting may only take effect after their next post.',
'Disable promotion'				=>	'Disable promoting',
'Mod privileges label'			=>	'Allow users moderator privileges',
'Mod privileges help'			=>	'In order for a user in this group to have moderator abilities, he/she must be assigned to moderate one or more forums. This is done via the user administration page of the user\'s profile.',
'Edit profile label'			=>	'Allow moderators to edit user profiles',
'Edit profile help'				=>	'If moderator privileges are enabled, allow users in this group to edit user profiles.',
'Rename users label'			=>	'Allow moderators to rename users',
'Rename users help'				=>	'If moderator privileges are enabled, allow users in this group to rename users.',
'Change passwords label'		=>	'Allow moderators to change passwords',
'Change passwords help'			=>	'If moderator privileges are enabled, allow users in this group to change user passwords.',
'Ban users label'				=>	'Allow moderators to ban users',
'Ban users help'				=>	'If moderator privileges are enabled, allow users in this group to ban users.',
'Read board label'				=>	'Read board',
'Read board help'				=>	'Allow users in this group to view the board. This setting applies to every aspect of the board and can therefore not be overridden by forum specific settings. If this is set to "No", users in this group will only be able to login/logout and register.',
'View user info label'			=>	'View user information',
'View user info help'			=>	'Allow users to view the user list and user profiles.',
'Post replies label'			=>	'Post replies',
'Post replies help'				=>	'Allow users in this group to post replies in topics.',
'Post topics label'				=>	'Post topics',
'Post topics help'				=>	'Allow users in this group to post new topics.',
'Edit posts label'				=>	'Edit posts',
'Edit posts help'				=>	'Allow users in this group to edit their own posts.',
'Delete posts label'			=>	'Delete posts',
'Delete posts help'				=>	'Allow users in this group to delete their own posts.',
'Delete topics label'			=>	'Delete topics',
'Delete topics help'			=>	'Allow users in this group to delete their own topics (including any replies).',
'Post links label'				=>	'Post links',
'Post links help'				=>	'Allow users in this group to include links in their posts. This setting also applies to signatures and the website field in users\' profiles.',
'Set own title label'			=>	'Set own user title',
'Set own title help'			=>	'Allow users in this group to set their own user title.',
'User search label'				=>	'Use search',
'User search help'				=>	'Allow users in this group to use the search feature.',
'User list search label'		=>	'Search user list',
'User list search help'			=>	'Allow users in this group to freetext search for users in the user list.',
'Send e-mails label'			=>	'Send e-mails',
'Send e-mails help'				=>	'Allow users in this group to send e-mails to other users.',
'Post flood label'				=>	'Post flood interval',
'Post flood help'				=>	'Number of seconds that users in this group have to wait between posts. Set to 0 to disable.',
'Search flood label'			=>	'Search flood interval',
'Search flood help'				=>	'Number of seconds that users in this group have to wait between searches. Set to 0 to disable.',
'E-mail flood label'			=>	'Email flood interval',
'E-mail flood help'				=>	'Number of seconds that users in this group have to wait between emails. Set to 0 to disable.',
'Report flood label'			=>	'Report flood interval',
'Report flood help'				=>	'Number of seconds that users in this group have to wait between reports. Set to 0 to disable.',
'Moderator info'				=>	'Please note that in order for a user in this group to have moderator abilities, he/she must be assigned to moderate one or more forums. This is done via the user administration page of the user\'s profile.',

);
